#!/bin/bash
set -e
set -o pipefail

export COMPONENT="master"
export MASTER_DATA_DIR="$RUNTIME_DIR/$COMPONENT/data"
export MASTER_CONFIG_DIR="$CONFIG_DIR/$COMPONENT"
export LOGS_FILE="$RUNTIME_DIR/logs/$COMPONENT.log"

__create_namespace() {
  log_proc_msg "Creating namespace: $KUBERNETES_NAMESPACE"

  local existing_namespace=$(sudo kubectl \
    --kubeconfig=$KUBECONFIG \
    get namespace -o json \
    | jq '.items[] | select(.metadata.name == "'$KUBERNETES_NAMESPACE'")')

  if [ -z "$existing_namespace" ]; then
    log_proc_msg "Creating a new namespace"
    local namespace_template="$INSTALLER_SCRIPTS_DIR/configs/namespace.yml.template"
    local namespace="$MASTER_CONFIG_DIR/namespace.yml"

    sed "s#{{NAMESPACE}}#$KUBERNETES_NAMESPACE#g" $namespace_template > $namespace

    sudo kubectl \
      --kubeconfig=$KUBECONFIG \
      create -f "$namespace"
  else
    log_proc_msg "Namespace already exists, skipping"
  fi
}

main() {
  if [ "$RUN_MODE" == "devmode" ] || [ "$RUN_MODE" == "onebox" ]; then
    log_proc_msg "No initialization required in dev mode"
  else
    log_proc_marker "Initializing kubernetes cluster"
    #__create_namespace
  fi
}

main
