#!/bin/bash
set -e
set -o pipefail

export COMPONENT="redis"
export REDIS_DATA_DIR="$RUNTIME_DIR/$COMPONENT/data"
export REDIS_CONFIG_DIR="$CONFIG_DIR/$COMPONENT"
export LOGS_FILE="$RUNTIME_DIR/logs/$COMPONENT.log"
export REDIS_INSTALL_SCRIPT="installRedis.sh"
export REDIS_IMAGE="$IMAGE_REGISTRY_URL/$REDIS_IMAGE:$RELEASE"

## Write logs of this script to component specific file
exec &> >(tee -a "$LOGS_FILE")

__validate_redis_envs() {
  log_proc_msg "Initializing redis environment variables"
  log_proc_msg "STATE_CONFIG_DIR: $STATE_CONFIG_DIR"
  log_proc_msg "REDIS_IP: $REDIS_IP"
  log_proc_msg "REDIS_PORT: $REDIS_PORT"
  log_proc_msg "IMAGE_REGISTRY_URL: $IMAGE_REGISTRY_URL"
}

__validate_redis_mounts() {
  log_proc_msg "Validating redis mounts"
  if [ ! -d "$REDIS_DATA_DIR" ]; then
    log_proc_msg "Creating data directory $REDIS_DATA_DIR"
    mkdir -p $REDIS_DATA_DIR
  else
    log_proc_msg "Data directory already present: $REDIS_DATA_DIR"
  fi

  if [ ! -d "$REDIS_CONFIG_DIR" ]; then
    log_proc_msg "Creating config directory $REDIS_CONFIG_DIR"
    mkdir -p $REDIS_CONFIG_DIR
  else
    log_proc_msg "Config directory already present: $REDIS_CONFIG_DIR"
  fi

  mkdir -p $REDIS_CONFIG_DIR/scripts
}

__update_redis_config() {
  log_proc_msg "Updating redis config files"
  cp -vr $INSTALLER_SCRIPTS_DIR/configs/redis.conf $REDIS_CONFIG_DIR/redis.conf
}

__install_redis_compose() {
  source "$INSTALLER_SCRIPTS_DIR/compose/$REDIS_INSTALL_SCRIPT"
}

__install_redis_kubernetes() {
  source "$INSTALLER_SCRIPTS_DIR/kubernetes/$REDIS_INSTALL_SCRIPT"
}

main() {
  log_proc_marker "Installing Redis"
  if [ "$RUN_MODE" == "devmode" ] || [ "$RUN_MODE" == "onebox" ]; then
    __validate_redis_envs
    __validate_redis_mounts
    __update_redis_config
    __install_redis_compose
  else
    __validate_redis_envs
    __validate_redis_mounts
    __update_redis_config
    __install_redis_kubernetes
  fi
  log_proc_msg "Redis installed successfully"
}

main
