-- Add route Roles
create or replace function set_route_role(
  httpVerb varchar, routePattern varchar, roleCode int)

  returns void as $$
  begin

    -- insert if not exists
    if not exists (select 1 from "routeRoles"
      where "httpVerb" = httpVerb and
        "routePattern" = routePattern and
        "roleCode" = roleCode
    ) then
      insert into "routeRoles" ("httpVerb", "routePattern", "roleCode",
        "createdAt", "updatedAt")
      values (httpVerb, routePattern, roleCode,
        now(), now());
    end if;
  end
$$ LANGUAGE plpgsql;

do $$
  begin
    -- set GET /clusters routeRoles
    perform set_route_role(
      routePattern := '/clusters',
      httpVerb := 'GET',
      roleCode := 6060
    );

    perform set_route_role(
      routePattern := '/clusters',
      httpVerb := 'GET',
      roleCode := 6000
    );

    perform set_route_role(
      routePattern := '/clusters',
      httpVerb := 'GET',
      roleCode := 6020
    );

    -- set POST /clusters routeRoles
    perform set_route_role(
      routePattern := '/clusters',
      httpVerb := 'POST',
      roleCode := 6020
    );

    -- set PUT /clusters/:clusterId routeRoles
    perform set_route_role(
      routePattern := '/clusters/:clusterId',
      httpVerb := 'PUT',
      roleCode := 6020
    );

    -- set DELETE /clusters/:clusterId routeRoles
    perform set_route_role(
      routePattern := '/clusters/:clusterId',
      httpVerb := 'DELETE',
      roleCode := 6020
    );

    -- set GET /clusterNodes routeRoles
    perform set_route_role(
      routePattern := '/clusterNodes',
      httpVerb := 'GET',
      roleCode := 6060
    );

    perform set_route_role(
      routePattern := '/clusterNodes',
      httpVerb := 'GET',
      roleCode := 6000
    );

    perform set_route_role(
      routePattern := '/clusterNodes',
      httpVerb := 'GET',
      roleCode := 6020
    );

    -- set GET /clusterNodes/:clusterNodeId routeRoles
    perform set_route_role(
      routePattern := '/clusterNodes/:clusterNodeId',
      httpVerb := 'GET',
      roleCode := 6000
    );

    perform set_route_role(
      routePattern := '/clusterNodes/:clusterNodeId',
      httpVerb := 'GET',
      roleCode := 6020
    );

    perform set_route_role(
      routePattern := '/clusterNodes/:clusterNodeId',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /clusterNodes/:clusterNodeId/validate routeRoles
     perform set_route_role(
       routePattern := '/clusterNodes/:clusterNodeId/validate',
       httpVerb := 'GET',
       roleCode := 6000
     );

     perform set_route_role(
       routePattern := '/clusterNodes/:clusterNodeId/validate',
       httpVerb := 'GET',
       roleCode := 6020
     );

     perform set_route_role(
       routePattern := '/clusterNodes/:clusterNodeId/validate',
       httpVerb := 'GET',
       roleCode := 6040
     );

     perform set_route_role(
       routePattern := '/clusterNodes/:clusterNodeId/validate',
       httpVerb := 'GET',
       roleCode := 6060
     );

    -- set GET /clusterNodes/:clusterNodeId/initScript routeRoles
    perform set_route_role(
      routePattern := '/clusterNodes/:clusterNodeId/initScript',
      httpVerb := 'GET',
      roleCode := 6000
    );

    perform set_route_role(
      routePattern := '/clusterNodes/:clusterNodeId/initScript',
      httpVerb := 'GET',
      roleCode := 6020
    );

    perform set_route_role(
      routePattern := '/clusterNodes/:clusterNodeId/initScript',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set DELETE /clusterNodes/:clusterNodeId routeRoles
    perform set_route_role(
      routePattern := '/clusterNodes/:clusterNodeId',
      httpVerb := 'DELETE',
      roleCode := 6020
    );

    -- set PUT /clusterNodes/:clusterNodeId routeRoles
    perform set_route_role(
      routePattern := '/clusterNodes/:clusterNodeId',
      httpVerb := 'PUT',
      roleCode := 6020
    );

    perform set_route_role(
      routePattern := '/clusterNodes/:clusterNodeId',
      httpVerb := 'PUT',
      roleCode := 6040
    );

    perform set_route_role(
      routePattern := '/clusterNodes/:clusterNodeId',
      httpVerb := 'PUT',
      roleCode := 6060
    );

    -- set POST /clusterNodes routeRoles
    perform set_route_role(
      routePattern := '/clusterNodes',
      httpVerb := 'POST',
      roleCode := 6020
    );

    -- set GET /clusterNodes/:clusterNodeId/clusterNodeConsoles route roles
    perform set_route_role(
      routePattern := '/clusterNodes/:clusterNodeId/clusterNodeConsoles',
      httpVerb := 'GET',
      roleCode := 6060
    );

    perform set_route_role(
      routePattern := '/clusterNodes/:clusterNodeId/clusterNodeConsoles',
      httpVerb := 'GET',
      roleCode := 6000
    );

    perform set_route_role(
      routePattern := '/clusterNodes/:clusterNodeId/clusterNodeConsoles',
      httpVerb := 'GET',
      roleCode := 6020
    );

    -- set GET /clusterNodeStats routeRoles
    perform set_route_role(
      routePattern := '/clusterNodeStats',
      httpVerb := 'GET',
      roleCode := 6000
    );

    perform set_route_role(
      routePattern := '/clusterNodeStats',
      httpVerb := 'GET',
      roleCode := 6020
    );

    perform set_route_role(
      routePattern := '/clusterNodeStats',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set POST /clusterNodeStats routeRoles
    perform set_route_role(
      routePattern := '/clusterNodeStats',
      httpVerb := 'POST',
      roleCode := 6020
    );

    perform set_route_role(
      routePattern := '/clusterNodeStats',
      httpVerb := 'POST',
      roleCode := 6040
    );

    -- set DELETE /clusterNodes/:clusterNodeId/clusterNodeStats routeRoles
    perform set_route_role(
      routePattern := '/clusterNodes/:clusterNodeId/clusterNodeStats',
      httpVerb := 'DELETE',
      roleCode := 6020
    );

    -- set GET /identities routeRoles
    perform set_route_role(
      routePattern := '/identities',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /identityRoles routeRoles
    perform set_route_role(
      routePattern := '/identityRoles',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /identityTokens routeRoles
    perform set_route_role(
      routePattern := '/identityTokens',
      httpVerb := 'GET',
      roleCode := 6060
    );

    perform set_route_role(
      routePattern := '/identityTokens',
      httpVerb := 'GET',
      roleCode := 6020
    );

    -- set GET /identityTokens/:identityTokenId routeRoles
    perform set_route_role(
      routePattern := '/identityTokens/:identityTokenId',
      httpVerb := 'GET',
      roleCode := 6060
    );

    perform set_route_role(
      routePattern := '/identityTokens/:identityTokenId',
      httpVerb := 'GET',
      roleCode := 6020
    );

    -- set POST /identityTokens routeRoles
    perform set_route_role(
      routePattern := '/identityTokens',
      httpVerb := 'POST',
      roleCode := 6060
    );

    perform set_route_role(
      routePattern := '/identityTokens',
      httpVerb := 'POST',
      roleCode := 6020
    );

    -- set GET /projectIntegrations routeRoles
    perform set_route_role(
      routePattern := '/projectIntegrations',
      httpVerb := 'GET',
      roleCode := 6060
    );

    perform set_route_role(
      routePattern := '/projectIntegrations',
      httpVerb := 'GET',
      roleCode := 6020
    );

    perform set_route_role(
      routePattern := '/projectIntegrations',
      httpVerb := 'GET',
      roleCode := 6000
    );

    -- set GET /projectIntegrations/:projectIntegrationId routeRoles
    perform set_route_role(
      routePattern := '/projectIntegrations/:projectIntegrationId',
      httpVerb := 'GET',
      roleCode := 6060
    );

    perform set_route_role(
      routePattern := '/projectIntegrations/:projectIntegrationId',
      httpVerb := 'GET',
      roleCode := 6020
    );

    perform set_route_role(
      routePattern := '/projectIntegrations/:projectIntegrationId',
      httpVerb := 'GET',
      roleCode := 6000
    );

    -- set GET /projectIntegrations/:projectIntegrationId/validateRepositoryOwnerToken routeRoles
    perform set_route_role(
      routePattern :=
        '/projectIntegrations/:projectIntegrationId/validateRepositoryOwnerToken',
      httpVerb := 'GET',
      roleCode := 6060
    );

    perform set_route_role(
      routePattern :=
        '/projectIntegrations/:projectIntegrationId/validateRepositoryOwnerToken',
      httpVerb := 'GET',
      roleCode := 6020
    );

    perform set_route_role(
      routePattern :=
        '/projectIntegrations/:projectIntegrationId/validateRepositoryOwnerToken',
      httpVerb := 'GET',
      roleCode := 6000
    );

    -- set POST /projectIntegrations/:projectIntegrationId/sendEmail routeRoles
    perform set_route_role(
      routePattern := '/projectIntegrations/:projectIntegrationId/sendEmail',
      httpVerb := 'POST',
      roleCode := 6020
    );

    perform set_route_role(
      routePattern := '/projectIntegrations/:projectIntegrationId/sendEmail',
      httpVerb := 'POST',
      roleCode := 6060
    );

    -- set POST /projectIntegrations routeRoles
    perform set_route_role(
      routePattern := '/projectIntegrations',
      httpVerb := 'POST',
      roleCode := 6020
    );

    -- set PUT /projectIntegrations/:projectIntegrationId routeRoles
    perform set_route_role(
      routePattern := '/projectIntegrations/:projectIntegrationId',
      httpVerb := 'PUT',
      roleCode := 6020
    );

    -- set DELETE /projectIntegrations/:projectIntegrationId routeRoles
    perform set_route_role(
      routePattern := '/projectIntegrations/:projectIntegrationId',
      httpVerb := 'DELETE',
      roleCode := 6020
    );

    -- set GET /masterIntegrations routeRoles
    perform set_route_role(
      routePattern := '/masterIntegrations',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /masterIntegrationFields routeRoles
    perform set_route_role(
      routePattern := '/masterIntegrationFields',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /masterIntegrationTypeCodes routeRoles
    perform set_route_role(
      routePattern := '/masterIntegrationTypeCodes',
      httpVerb := 'GET',
      roleCode := 6040
    );

    -- set passthrough routeRoles

    -- set GET /passthrough/nodes/scripts routeRoles
    perform set_route_role(
      routePattern := '/passthrough/nodes/scripts',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /passthrough/nodes/platforms routeRoles
    perform set_route_role(
      routePattern := '/passthrough/nodes/platforms',
      httpVerb := 'GET',
      roleCode := 6060
    );

    --set GET /payments/clienttoken routeRoles
    perform set_route_role(
      routePattern := '/payments/clienttoken',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /pipelines routeRoles
    perform set_route_role(
      routePattern := '/pipelines',
      httpVerb := 'GET',
      roleCode := 6060
    );

    perform set_route_role(
      routePattern := '/pipelines',
      httpVerb := 'GET',
      roleCode := 6020
    );

    perform set_route_role(
      routePattern := '/pipelines',
      httpVerb := 'GET',
      roleCode := 6000
    );

    -- set GET /pipelines/:pipelineId routeRoles
    perform set_route_role(
      routePattern := '/pipelines/:pipelineId',
      httpVerb := 'GET',
      roleCode := 6060
    );

    perform set_route_role(
      routePattern := '/pipelines/:pipelineId',
      httpVerb := 'GET',
      roleCode := 6020
    );

    perform set_route_role(
      routePattern := '/pipelines/:pipelineId',
      httpVerb := 'GET',
      roleCode := 6000
    );

    -- set GET /pipelines/:pipelineId/artifactUrl routeRoles
    perform set_route_role(
      routePattern := '/pipelines/:pipelineId/artifactUrl',
      httpVerb := 'GET',
      roleCode := 6000
    );

    perform set_route_role(
      routePattern := '/pipelines/:pipelineId/artifactUrl',
      httpVerb := 'GET',
      roleCode := 6020
    );

    perform set_route_role(
      routePattern := '/pipelines/:pipelineId/artifactUrl',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /pipelines/:pipelineId/latestState routeRoles
    perform set_route_role(
      routePattern := '/pipelines/:pipelineId/latestState',
      httpVerb := 'GET',
      roleCode := 6000
    );

    perform set_route_role(
      routePattern := '/pipelines/:pipelineId/latestState',
      httpVerb := 'GET',
      roleCode := 6020
    );

    perform set_route_role(
      routePattern := '/pipelines/:pipelineId/latestState',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /pipelines/:pipelineId/artifacts routeRoles
    perform set_route_role(
      routePattern := '/pipelines/:pipelineId/artifacts',
      httpVerb := 'GET',
      roleCode := 6000
    );

    perform set_route_role(
      routePattern := '/pipelines/:pipelineId/artifacts',
      httpVerb := 'GET',
      roleCode := 6020
    );

    perform set_route_role(
      routePattern := '/pipelines/:pipelineId/artifacts',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /pipelineSources routeRoles
    perform set_route_role(
      routePattern := '/pipelineSources',
      httpVerb := 'GET',
      roleCode := 6060
    );

    perform set_route_role(
      routePattern := '/pipelineSources',
      httpVerb := 'GET',
      roleCode := 6020
    );

    perform set_route_role(
      routePattern := '/pipelineSources',
      httpVerb := 'GET',
      roleCode := 6000
    );

    -- set GET /pipelineSources/:pipelineSourceId routeRoles
    perform set_route_role(
      routePattern := '/pipelineSources/:pipelineSourceId',
      httpVerb := 'GET',
      roleCode := 6060
    );

    perform set_route_role(
      routePattern := '/pipelineSources/:pipelineSourceId',
      httpVerb := 'GET',
      roleCode := 6020
    );

    perform set_route_role(
      routePattern := '/pipelineSources/:pipelineSourceId',
      httpVerb := 'GET',
      roleCode := 6000
    );

    -- set PUT /pipelineSources/:pipelineSourceId routeRoles
    perform set_route_role(
      routePattern := '/pipelineSources/:pipelineSourceId',
      httpVerb := 'PUT',
      roleCode := 6020
    );

    -- set POST /pipelineSources routeRoles
    perform set_route_role(
      routePattern := '/pipelineSources',
      httpVerb := 'POST',
      roleCode := 6020
    );

    -- set DELETE /pipelineSources/:pipelineSourceId routeRoles
    perform set_route_role(
      routePattern := '/pipelineSources/:pipelineSourceId',
      httpVerb := 'DELETE',
      roleCode := 6020
    );

    -- set GET /pipelineStepConnections routeRoles
    perform set_route_role(
      routePattern := '/pipelineStepConnections',
      httpVerb := 'GET',
      roleCode := 6060
    );

    perform set_route_role(
      routePattern := '/pipelineStepConnections',
      httpVerb := 'GET',
      roleCode := 6020
    );

    perform set_route_role(
      routePattern := '/pipelineStepConnections',
      httpVerb := 'GET',
      roleCode := 6000
    );

    -- set GET /pipelineStepConnections/:pipelineStepConnectionId routeRoles
    perform set_route_role(
      routePattern := '/pipelineStepConnections/:pipelineStepConnectionId',
      httpVerb := 'GET',
      roleCode := 6060
    );

    perform set_route_role(
      routePattern := '/pipelineStepConnections/:pipelineStepConnectionId',
      httpVerb := 'GET',
      roleCode := 6020
    );

    perform set_route_role(
      routePattern := '/pipelineStepConnections/:pipelineStepConnectionId',
      httpVerb := 'GET',
      roleCode := 6000
    );

    -- set GET /pipelineSteps routeRoles
    perform set_route_role(
      routePattern := '/pipelineSteps',
      httpVerb := 'GET',
      roleCode := 6060
    );

    perform set_route_role(
      routePattern := '/pipelineSteps',
      httpVerb := 'GET',
      roleCode := 6020
    );

    perform set_route_role(
      routePattern := '/pipelineSteps',
      httpVerb := 'GET',
      roleCode := 6000
    );

    -- set GET /pipelineSteps/:pipelineStepId routeRoles
    perform set_route_role(
      routePattern := '/pipelineSteps/:pipelineStepId',
      httpVerb := 'GET',
      roleCode := 6060
    );

    perform set_route_role(
      routePattern := '/pipelineSteps/:pipelineStepId',
      httpVerb := 'GET',
      roleCode := 6020
    );

    perform set_route_role(
      routePattern := '/pipelineSteps/:pipelineStepId',
      httpVerb := 'GET',
      roleCode := 6000
    );

    -- set GET /pipelineSteps/:pipelineStepId/latestArchive routeRoles
    perform set_route_role(
      routePattern := '/pipelineSteps/:pipelineStepId/latestArchive',
      httpVerb := 'GET',
      roleCode := 6060
    );

    perform set_route_role(
      routePattern := '/pipelineSteps/:pipelineStepId/latestArchive',
      httpVerb := 'GET',
      roleCode := 6020
    );

    perform set_route_role(
      routePattern := '/pipelineSteps/:pipelineStepId/latestArchive',
      httpVerb := 'GET',
      roleCode := 6000
    );


    -- set POST /pipelineSteps/:pipelineStepId/trigger routeRoles
    perform set_route_role(
      routePattern := '/pipelineSteps/:pipelineStepId/trigger',
      httpVerb := 'POST',
      roleCode := 6020
    );

    -- set GET /projects routeRoles
    perform set_route_role(
      routePattern := '/projects',
      httpVerb := 'GET',
      roleCode := 6060
    );

    perform set_route_role(
      routePattern := '/projects',
      httpVerb := 'GET',
      roleCode := 6020
    );

    perform set_route_role(
      routePattern := '/projects',
      httpVerb := 'GET',
      roleCode := 6000
    );

    -- set GET /projects/:projectId routeRoles
    perform set_route_role(
      routePattern := '/projects/:projectId',
      httpVerb := 'GET',
      roleCode := 6060
    );

    perform set_route_role(
      routePattern := '/projects/:projectId',
      httpVerb := 'GET',
      roleCode := 6020
    );

    perform set_route_role(
      routePattern := '/projects/:projectId',
      httpVerb := 'GET',
      roleCode := 6000
    );

    -- set GET /projects/:projectId/state routeRoles
    perform set_route_role(
      routePattern := '/projects/:projectId/state',
      httpVerb := 'GET',
      roleCode := 6060
    );

    perform set_route_role(
      routePattern := '/projects/:projectId/state',
      httpVerb := 'GET',
      roleCode := 6020
    );

    perform set_route_role(
      routePattern := '/projects/:projectId/state',
      httpVerb := 'GET',
      roleCode := 6000
    );

    -- set GET /projectPermissions routeRoles
    perform set_route_role(
      routePattern := '/projectPermissions',
      httpVerb := 'GET',
      roleCode := 6060
    );

    perform set_route_role(
      routePattern := '/projectPermissions',
      httpVerb := 'GET',
      roleCode := 6020
    );

    perform set_route_role(
      routePattern := '/projectPermissions',
      httpVerb := 'GET',
      roleCode := 6000
    );

    -- set GET /providers/:providerId routeRoles
    perform set_route_role(
      routePattern := '/providers/:providerId',
      httpVerb := 'GET',
      roleCode := 6040
    );

    perform set_route_role(
      routePattern := '/providers/:providerId',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /providers routeRoles
    perform set_route_role(
      routePattern := '/providers',
      httpVerb := 'GET',
      roleCode := 6040
    );

    perform set_route_role(
      routePattern := '/providers',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /resources routeRoles
    perform set_route_role(
      routePattern := '/resources',
      httpVerb := 'GET',
      roleCode := 6000
    );

    perform set_route_role(
      routePattern := '/resources',
      httpVerb := 'GET',
      roleCode := 6020
    );

    perform set_route_role(
      routePattern := '/resources',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /resources/:resourceId routeRoles
    perform set_route_role(
      routePattern := '/resources/:resourceId',
      httpVerb := 'GET',
      roleCode := 6000
    );

    perform set_route_role(
      routePattern := '/resources/:resourceId',
      httpVerb := 'GET',
      roleCode := 6020
    );

    perform set_route_role(
      routePattern := '/resources/:resourceId',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set PUT /resources/:resourceId routeRoles
    perform set_route_role(
      routePattern := '/resources/:resourceId',
      httpVerb := 'PUT',
      roleCode := 6020
    );

    -- set GET /resources/:resourceId/artifactUrl routeRoles
    perform set_route_role(
      routePattern := '/resources/:resourceId/artifactUrl',
      httpVerb := 'GET',
      roleCode := 6000
    );

    perform set_route_role(
      routePattern := '/resources/:resourceId/artifactUrl',
      httpVerb := 'GET',
      roleCode := 6020
    );

    perform set_route_role(
      routePattern := '/resources/:resourceId/artifactUrl',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /resourceVersions routeRoles
    perform set_route_role(
      routePattern := '/resourceVersions',
      httpVerb := 'GET',
      roleCode := 6000
    );

    perform set_route_role(
      routePattern := '/resourceVersions',
      httpVerb := 'GET',
      roleCode := 6020
    );

    perform set_route_role(
      routePattern := '/resourceVersions',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /resourceVersions/:resourceVersionId routeRoles
    perform set_route_role(
      routePattern := '/resourceVersions/:resourceVersionId',
      httpVerb := 'GET',
      roleCode := 6000
    );

    perform set_route_role(
      routePattern := '/resourceVersions/:resourceVersionId',
      httpVerb := 'GET',
      roleCode := 6020
    );

    perform set_route_role(
      routePattern := '/resourceVersions/:resourceVersionId',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set POST /resourceVersions routeRoles
    perform set_route_role(
      routePattern := '/resourceVersions',
      httpVerb := 'POST',
      roleCode := 6020
    );

    perform set_route_role(
      routePattern := '/resourceVersions',
      httpVerb := 'POST',
      roleCode := 6060
    );

    -- set GET /runResourceVersions routeRoles
    perform set_route_role(
      routePattern := '/runResourceVersions',
      httpVerb := 'GET',
      roleCode := 6000
    );

    perform set_route_role(
      routePattern := '/runResourceVersions',
      httpVerb := 'GET',
      roleCode := 6020
    );

    perform set_route_role(
      routePattern := '/runResourceVersions',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /runResourceVersions/:runResourceVersionId routeRoles
    perform set_route_role(
      routePattern := '/runResourceVersions/:runResourceVersionId',
      httpVerb := 'GET',
      roleCode := 6000
    );

    perform set_route_role(
      routePattern := '/runResourceVersions/:runResourceVersionId',
      httpVerb := 'GET',
      roleCode := 6020
    );

    perform set_route_role(
      routePattern := '/runResourceVersions/:runResourceVersionId',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /runs routeRoles
    perform set_route_role(
      routePattern := '/runs',
      httpVerb := 'GET',
      roleCode := 6000
    );

    perform set_route_role(
      routePattern := '/runs',
      httpVerb := 'GET',
      roleCode := 6020
    );

    perform set_route_role(
      routePattern := '/runs',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /runs/:runId routeRoles
    perform set_route_role(
      routePattern := '/runs/:runId',
      httpVerb := 'GET',
      roleCode := 6000
    );

    perform set_route_role(
      routePattern := '/runs/:runId',
      httpVerb := 'GET',
      roleCode := 6020
    );

    perform set_route_role(
      routePattern := '/runs/:runId',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /runs/:runId/artifactUrl routeRoles
    perform set_route_role(
      routePattern := '/runs/:runId/artifactUrl',
      httpVerb := 'GET',
      roleCode := 6000
    );

    perform set_route_role(
      routePattern := '/runs/:runId/artifactUrl',
      httpVerb := 'GET',
      roleCode := 6020
    );

    perform set_route_role(
      routePattern := '/runs/:runId/artifactUrl',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /runs/:runId/artifacts routeRoles
    perform set_route_role(
      routePattern := '/runs/:runId/artifacts',
      httpVerb := 'GET',
      roleCode := 6000
    );

    perform set_route_role(
      routePattern := '/runs/:runId/artifacts',
      httpVerb := 'GET',
      roleCode := 6020
    );

    perform set_route_role(
      routePattern := '/runs/:runId/artifacts',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set POST /runs/:runId/nextSteps routeRoles
    perform set_route_role(
      routePattern := '/runs/:runId/nextSteps',
      httpVerb := 'POST',
      roleCode := 6020
    );

    perform set_route_role(
      routePattern := '/runs/:runId/nextSteps',
      httpVerb := 'POST',
      roleCode := 6060
    );

    -- set GET /runStepConnections routeRoles
    perform set_route_role(
      routePattern := '/runStepConnections',
      httpVerb := 'GET',
      roleCode := 6000
    );

    perform set_route_role(
      routePattern := '/runStepConnections',
      httpVerb := 'GET',
      roleCode := 6020
    );

    perform set_route_role(
      routePattern := '/runStepConnections',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /runStepConnections/:runStepConnectionId routeRoles
    perform set_route_role(
      routePattern := '/runStepConnections/:runStepConnectionId',
      httpVerb := 'GET',
      roleCode := 6000
    );

    perform set_route_role(
      routePattern := '/runStepConnections/:runStepConnectionId',
      httpVerb := 'GET',
      roleCode := 6020
    );

    perform set_route_role(
      routePattern := '/runStepConnections/:runStepConnectionId',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /steps/:stepId/consoles routeRoles
    perform set_route_role(
      routePattern := '/steps/:stepId/consoles',
      httpVerb := 'GET',
      roleCode := 6000
    );

    perform set_route_role(
      routePattern := '/steps/:stepId/consoles',
      httpVerb := 'GET',
      roleCode := 6020
    );

    perform set_route_role(
      routePattern := '/steps/:stepId/consoles',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set POST /stepConsoles routeRoles
    perform set_route_role(
      routePattern := '/stepConsoles',
      httpVerb := 'POST',
      roleCode := 6020
    );

    perform set_route_role(
      routePattern := '/stepConsoles',
      httpVerb := 'POST',
      roleCode := 6060
    );

    -- set GET /steplets/:stepletId/consoles routeRoles
    perform set_route_role(
      routePattern := '/steplets/:stepletId/consoles',
      httpVerb := 'GET',
      roleCode := 6000
    );

    perform set_route_role(
      routePattern := '/steplets/:stepletId/consoles',
      httpVerb := 'GET',
      roleCode := 6020
    );

    perform set_route_role(
      routePattern := '/steplets/:stepletId/consoles',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set POST /stepletConsoles routeRoles
    perform set_route_role(
      routePattern := '/stepletConsoles',
      httpVerb := 'POST',
      roleCode := 6020
    );

    perform set_route_role(
      routePattern := '/stepletConsoles',
      httpVerb := 'POST',
      roleCode := 6060
    );

    -- set GET /steplets routeRoles
    perform set_route_role(
      routePattern := '/steplets',
      httpVerb := 'GET',
      roleCode := 6000
    );

    perform set_route_role(
      routePattern := '/steplets',
      httpVerb := 'GET',
      roleCode := 6020
    );

    perform set_route_role(
      routePattern := '/steplets',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /steplets/:stepletId routeRoles
    perform set_route_role(
      routePattern := '/steplets/:stepletId',
      httpVerb := 'GET',
      roleCode := 6000
    );

    perform set_route_role(
      routePattern := '/steplets/:stepletId',
      httpVerb := 'GET',
      roleCode := 6020
    );

    perform set_route_role(
      routePattern := '/steplets/:stepletId',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set PUT /steplets/:stepletId routeRoles
    perform set_route_role(
      routePattern := '/steplets/:stepletId',
      httpVerb := 'PUT',
      roleCode := 6020
    );

    perform set_route_role(
      routePattern := '/steplets/:stepletId',
      httpVerb := 'PUT',
      roleCode := 6060
    );

    -- set GET /steplets/:stepletId/artifactUrl routeRoles
    perform set_route_role(
      routePattern := '/steplets/:stepletId/artifactUrl',
      httpVerb := 'GET',
      roleCode := 6000
    );

    perform set_route_role(
      routePattern := '/steplets/:stepletId/artifactUrl',
      httpVerb := 'GET',
      roleCode := 6020
    );

    perform set_route_role(
      routePattern := '/steplets/:stepletId/artifactUrl',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /stepTestReports routeRoles
    perform set_route_role(
      routePattern := '/stepTestReports',
      httpVerb := 'GET',
      roleCode := 6000
    );

    perform set_route_role(
      routePattern := '/stepTestReports',
      httpVerb := 'GET',
      roleCode := 6020
    );

    perform set_route_role(
      routePattern := '/stepTestReports',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /step/:stepId/stepTestReports routeRoles
    perform set_route_role(
      routePattern := '/step/:stepId/stepTestReports',
      httpVerb := 'GET',
      roleCode := 6000
    );

    perform set_route_role(
      routePattern := '/step/:stepId/stepTestReports',
      httpVerb := 'GET',
      roleCode := 6020
    );

    perform set_route_role(
      routePattern := '/step/:stepId/stepTestReports',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set POST /stepTestReports routeRoles
    perform set_route_role(
      routePattern := '/stepTestReports',
      httpVerb := 'POST',
      roleCode := 6020
    );

    perform set_route_role(
      routePattern := '/stepTestReports',
      httpVerb := 'POST',
      roleCode := 6060
    );

    -- set GET /steps routeRoles
    perform set_route_role(
      routePattern := '/steps',
      httpVerb := 'GET',
      roleCode := 6000
    );

    perform set_route_role(
      routePattern := '/steps',
      httpVerb := 'GET',
      roleCode := 6020
    );

    perform set_route_role(
      routePattern := '/steps',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /steps/:stepId routeRoles
    perform set_route_role(
      routePattern := '/steps/:stepId',
      httpVerb := 'GET',
      roleCode := 6000
    );

    perform set_route_role(
      routePattern := '/steps/:stepId',
      httpVerb := 'GET',
      roleCode := 6020
    );

    perform set_route_role(
      routePattern := '/steps/:stepId',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set PUT /steps/:stepId routeRoles
    perform set_route_role(
      routePattern := '/steps/:stepId',
      httpVerb := 'PUT',
      roleCode := 6020
    );

    perform set_route_role(
      routePattern := '/steps/:stepId',
      httpVerb := 'PUT',
      roleCode := 6060
    );

    -- set GET /steps/:stepId/artifactUrl routeRoles
    perform set_route_role(
      routePattern := '/steps/:stepId/artifactUrl',
      httpVerb := 'GET',
      roleCode := 6000
    );

    perform set_route_role(
      routePattern := '/steps/:stepId/artifactUrl',
      httpVerb := 'GET',
      roleCode := 6020
    );

    perform set_route_role(
      routePattern := '/steps/:stepId/artifactUrl',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /steps/:stepId/reports routeRoles
    perform set_route_role(
      routePattern := '/steps/:stepId/reports',
      httpVerb := 'GET',
      roleCode := 6000
    );

    perform set_route_role(
      routePattern := '/steps/:stepId/reports',
      httpVerb := 'GET',
      roleCode := 6020
    );

    perform set_route_role(
      routePattern := '/steps/:stepId/reports',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /systemRuntimeLanguages routeRoles
    perform set_route_role(
      routePattern := '/systemRuntimeLanguages',
      httpVerb := 'GET',
      roleCode := 6000
    );

    perform set_route_role(
      routePattern := '/systemRuntimeLanguages',
      httpVerb := 'GET',
      roleCode := 6020
    );

    perform set_route_role(
      routePattern := '/systemRuntimeLanguages',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /systemRuntimeTemplates routeRoles
    perform set_route_role(
      routePattern := '/systemRuntimeTemplates',
      httpVerb := 'GET',
      roleCode := 6000
    );

    perform set_route_role(
      routePattern := '/systemRuntimeTemplates',
      httpVerb := 'GET',
      roleCode := 6020
    );

    perform set_route_role(
      routePattern := '/systemRuntimeTemplates',
      httpVerb := 'GET',
      roleCode := 6040
    );

    perform set_route_role(
      routePattern := '/systemRuntimeTemplates',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /systemMachineImages routes

    perform set_route_role(
      routePattern := '/systemMachineImages',
      httpVerb := 'GET',
      roleCode := 6000
    );

    perform set_route_role(
      routePattern := '/systemMachineImages',
      httpVerb := 'GET',
      roleCode := 6020
    );

    perform set_route_role(
      routePattern := '/systemMachineImages',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /systemMachineImages/:systemMachineImageId routes
    perform set_route_role(
      routePattern := '/systemMachineImages/:systemMachineImageId',
      httpVerb := 'GET',
      roleCode := 6000
    );

    perform set_route_role(
      routePattern := '/systemMachineImages/:systemMachineImageId',
      httpVerb := 'GET',
      roleCode := 6020
    );

    perform set_route_role(
      routePattern := '/systemMachineImages/:systemMachineImageId',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set POST /vortex routeRoles
    perform set_route_role(
      routePattern := '/vortex',
      httpVerb := 'POST',
      roleCode := 6060
    );

    -- set GET /vortex routeRoles
    perform set_route_role(
      routePattern := '/vortex',
      httpVerb := 'GET',
      roleCode := 6060
    );

    -- set GET /systemCodes routeRoles
    perform set_route_role(
      routePattern := '/systemCodes',
      httpVerb := 'GET',
      roleCode := 6040
    );
  end
$$;
