#!/bin/bash

set -e
set -o pipefail

export COMPONENT="db"
export DB_DATA_DIR="$RUNTIME_DIR/$COMPONENT/data"
export DB_CONFIG_DIR="$CONFIG_DIR/$COMPONENT"
export DB_COMPOSE="$DB_CONFIG_DIR/db_compose.yml"

__test_db_connection() {
  local create_table_cmd="PGPASSWORD=$DB_PASSWORD \
    psql \
    -U $DB_USER \
    -d $DB_NAME \
    -h $DB_IP \
    -p $DB_PORT \
    -v ON_ERROR_STOP=1 \
    -c 'CREATE TABLE \"pipelinesTestTable\" (\"testColumn\" integer PRIMARY KEY);'"
  local drop_table_cmd="PGPASSWORD=$DB_PASSWORD \
    psql \
    -U $DB_USER \
    -d $DB_NAME \
    -h $DB_IP \
    -p $DB_PORT \
    -v ON_ERROR_STOP=1 \
    -c 'DROP TABLE \"pipelinesTestTable\";'"
    log_proc_msg "Creating a test table to verify database connection"
    eval "$create_table_cmd"
    log_proc_msg "Dropping a test table"
    eval "$drop_table_cmd"
    log_proc_msg "Successfully tested connection to $DB_IP $DB_PORT"
}

__start_db_compose() {
  log_proc_msg "Starting database container"
  docker-compose \
    --file $DB_COMPOSE down || true

  docker-compose \
    --file $DB_COMPOSE \
    up \
    --detach $COMPONENT
	# wait for db to boot up
	sleep 10
}

main() {
  if [ "$RUN_MODE" == "devmode" ] || [ "$RUN_MODE" == "onebox" ]; then
    __start_db_compose
    __test_db_connection
  else
    log_proc_msg "Connecting to existing database"
    log_proc_msg "DB_IP: $DB_IP"
    log_proc_msg "DB_USER: $DB_USER"
    log_proc_msg "DB_NAME: $DB_NAME"
    __test_db_connection
  fi
}

main
