#!/bin/bash
set -e
set -o pipefail

export COMPONENT="msg"
export MSG_CONFIG_DIR="$CONFIG_DIR/$COMPONENT"
export MSG_COMPOSE="$MSG_CONFIG_DIR/msg_compose.yml"

__check_msg() {
  log_proc_msg "Checking rabbitmq container status on: $RABBITMQ_IP:$RABBITMQ_PORT"

  platform_exec "check_service_connection" "$RABBITMQ_IP" "$RABBITMQ_PORT" "$COMPONENT"
  platform_exec "check_service_connection" "$RABBITMQ_IP" "$RABBITMQ_ADMIN_PORT" "MSG_ADMIN"
}

__restart_msg_compose() {
  log_proc_msg "Running rabbitmq container"
  docker-compose \
    --file $MSG_COMPOSE down || true

  docker-compose \
    --file $MSG_COMPOSE \
    up \
    --detach $COMPONENT

  log_proc_msg "RabbitMQ container successfully running"
}

__restart_msg_kubernetes() {
  log_proc_warn "RabbitMQ kubernetes service should be restarted manually"
}

main() {
  log_proc_marker "Restarting Msg"
  if [ "$RUN_MODE" == "devmode" ] || [ "$RUN_MODE" == "onebox" ]; then
    __restart_msg_compose
  else
    __restart_msg_kubernetes
  fi
  __check_msg
}

main
