#!/bin/bash
set -e
set -o pipefail

export COMPONENT="redis"
export REDIS_CONFIG_DIR="$CONFIG_DIR/$COMPONENT"
export REDIS_COMPOSE="$REDIS_CONFIG_DIR/redis_compose.yml"

__check_redis() {
  log_proc_msg "Checking redis container status on: $REDIS_IP:$REDIS_PORT"
  platform_exec "check_service_connection" "$REDIS_IP" "$REDIS_PORT" "$COMPONENT"
}

__restart_redis_compose() {
  log_proc_msg "Running redis container"
  docker-compose \
    --file $REDIS_COMPOSE down || true

  docker-compose \
    --file $REDIS_COMPOSE \
    up \
    --detach $COMPONENT

  log_proc_msg "Redis container successfully running"
}

__restart_redis_kubernetes() {
  log_proc_warn "Redis kubernetes service should be restarted manually"
}

main() {
  log_proc_marker "Restarting Redis"
  if [ "$RUN_MODE" == "devmode" ] || [ "$RUN_MODE" == "onebox" ]; then
    __restart_redis_compose
  else
    __restart_redis_kubernetes
  fi
  __check_redis
}

main
