#!/bin/bash
set -e
set -o pipefail

__stop_installer() {
  log_proc_msg "Checking if installer is running"
  local installer_container=$(docker ps -a \
    | grep installer \
    | awk '{print $1}')

  if [ "$installer_container" != "" ]; then
    log_proc_msg "Stopping running installer container: $installer_container"
    docker stop -t=0 $installer_container
    docker rm -v $installer_container
  fi
}

boot_installer() {
  log_proc_marker "Booting installer"

  local image_tag="$RELEASE"
  if [ ! -z "$1" ]; then
    image_tag="$1"
  fi
  __stop_installer

  log_proc_msg "Generating installer ENV variables"
  local envs=" -e DBNAME=$DB_NAME \
    -e DBUSERNAME=$DB_USER \
    -e DBPASSWORD=$DB_PASSWORD \
    -e DBDIALECT=$DB_DIALECT \
    -e DBHOST=$DB_IP \
    -e DBPORT=$DB_PORT \
    -e RUN_MODE=$RUN_MODE \
    -e INSTALL_USER=$INSTALL_USER \
    -e INSTALL_GROUP=$INSTALL_GROUP \
    -e SERVICE_ID=$SERVICE_ID \
    -e RT_URL=$RT_URL \
    -e RT_USERNAME=$RT_USERNAME \
    -e RT_PASSWORD='$RT_PASSWORD' \
    -e INSTALLER_IP=$INSTALLER_IP \
    -e INSTALLER_AUTH_TOKEN=$INSTALLER_AUTH_TOKEN \
    -e CONFIG_DIR=$CONFIG_DIR \
    -e IGNORE_TLS_ERRORS=$IGNORE_TLS_ERRORS \
    -e RELEASE=$image_tag \
    -e RUNTIME_DIR=$RUNTIME_DIR"

  if [ ! -z "$PIPELINES_HTTP_PROXY" ]; then
    envs="$envs \
      -e http_proxy=$PIPELINES_HTTP_PROXY"
  fi

  if [ ! -z "$PIPELINES_HTTPS_PROXY" ]; then
    envs="$envs \
      -e https_proxy=$PIPELINES_HTTPS_PROXY"
  fi

  if [ ! -z "$PIPELINES_NO_PROXY" ]; then
    envs="$envs \
      -e no_proxy=$PIPELINES_NO_PROXY"
  fi

  if [ "$NO_VERIFY_SSL" == true ]; then
    envs="$envs \
      -e NODE_TLS_REJECT_UNAUTHORIZED=0"
  fi

  log_proc_msg "Generating installer  mounts"
  local mounts=" -v $CONFIG_DIR:$CONFIG_DIR \
    -v $RUNTIME_DIR:$RUNTIME_DIR \
    -v /var/run/docker.sock:/var/run/docker.sock"

  local installer_image="$IMAGE_REGISTRY_URL/$INSTALLER_IMAGE:$image_tag"

  local boot_cmd="docker run -d \
    $envs \
    $mounts \
    --publish 50003:50003 \
    --net=host \
    --privileged=true \
    --name=installer \
    --restart=unless-stopped \
    $installer_image"

  eval "$boot_cmd"
  log_proc_msg "Installer container successfully running"
}
